# DomainInspectorEntryDimensions

The unique combination of dimensions associated with this timeseries.

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**region** | **str** | The geographic region from which the edge responses in this data entry were delivered. If unspecified, results are aggregated across regions. | [optional] 
**datacenter** | **str** | The POP from which the edge responses in this data entry were delivered. If unspecified, results are aggregated across POPs. | [optional] 
**domain** | **str** | The domain from which the edge responses in this data entry were delivered. If unspecified, results are aggregated across domains. | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


